<?php

namespace Assetdocs\Assetrequest\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Assetrequest\Interfaces\AssetreqdtlRepositoryInterface;
use Assetdocs\Assetrequest\Repositories\Presenter\AssetreqdtlItemTransformer;

/**
 * Pubic API controller class.
 */
class AssetreqdtlApiController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Assetreqdtl\Interfaces\AssetreqdtlRepositoryInterface $assetreqdtl
     *
     * @return type
     */
    public function __construct(AssetreqdtlRepositoryInterface $assetreqdtl)
    {
        $this->middleware('api');

        $this->repository = $assetreqdtl;
        parent::__construct();
    }

    /**
     * Show assetreqdtl's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $assetreqdtls = $this->repository
            ->pushCriteria(new \Assetdocs\Assetrequest\Repositories\Criteria\AssetreqdtlPublicCriteria())
            ->setPresenter('\\Assetdocs\\Assetrequest\\Repositories\\Presenter\\AssetreqdtlListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $assetreqdtls['code'] = 2000;
        return response()->json($assetreqdtls)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show assetreqdtl.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $assetreqdtl = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($assetreqdtl)) {
            $assetreqdtl         = $this->itemPresenter($module, new AssetreqdtlItemTransformer);
            $assetreqdtl['code'] = 2001;
            return response()->json($assetreqdtl)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
