<?php

namespace Assetdocs\Assetrequest\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Assetrequest\Interfaces\AssetreqhdRepositoryInterface;
use Assetdocs\Assetrequest\Repositories\Presenter\AssetreqhdItemTransformer;

/**
 * Pubic API controller class.
 */
class AssetreqhdApiController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Assetreqhd\Interfaces\AssetreqhdRepositoryInterface $assetreqhd
     *
     * @return type
     */
    public function __construct(AssetreqhdRepositoryInterface $assetreqhd)
    {
        $this->middleware('api');

        $this->repository = $assetreqhd;
        parent::__construct();
    }

    /**
     * Show assetreqhd's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $assetreqhds = $this->repository
            ->pushCriteria(new \Assetdocs\Assetrequest\Repositories\Criteria\AssetreqhdPublicCriteria())
            ->setPresenter('\\Assetdocs\\Assetrequest\\Repositories\\Presenter\\AssetreqhdListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $assetreqhds['code'] = 2000;
        return response()->json($assetreqhds)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show assetreqhd.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $assetreqhd = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($assetreqhd)) {
            $assetreqhd         = $this->itemPresenter($module, new AssetreqhdItemTransformer);
            $assetreqhd['code'] = 2001;
            return response()->json($assetreqhd)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
