<?php

namespace Assetdocs\Assetrequest\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Form;
use Assetdocs\Assetrequest\Http\Requests\AssetreqhdUserWebRequest;
use Assetdocs\Assetrequest\Interfaces\AssetreqhdRepositoryInterface;
use Assetdocs\Assetrequest\Models\Assetreqhd;

class AssetreqhdUserController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'web';

    /**
     * Initialize assetreqhd controller.
     *
     * @param type AssetreqhdRepositoryInterface $assetreqhd
     *
     * @return type
     */
    public function __construct(AssetreqhdRepositoryInterface $assetreqhd)
    {
        $this->middleware('web');
        $this->middleware('auth:web');
        $this->setupTheme(config('theme.themes.user.theme'), config('theme.themes.user.layout'));

        $this->repository = $assetreqhd;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(AssetreqhdUserWebRequest $request)
    {
        $this->repository->pushCriteria(new \Assetdocs\Assetrequest\Repositories\Criteria\AssetreqhdUserCriteria());
        $assetreqhds = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('assetrequest::assetreqhd.names').' :: ');

        return $this->theme->of('assetrequest::user.assetreqhd.index', compact('assetreqhds'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Assetreqhd $assetreqhd
     *
     * @return Response
     */
    public function show(AssetreqhdUserWebRequest $request, Assetreqhd $assetreqhd)
    {
        Form::populate($assetreqhd);

        return $this->theme->of('assetrequest::user.assetreqhd.show', compact('assetreqhd'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(AssetreqhdUserWebRequest $request)
    {

        $assetreqhd = $this->repository->newInstance([]);
        Form::populate($assetreqhd);

        return $this->theme->of('assetrequest::user.assetreqhd.create', compact('assetreqhd'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AssetreqhdUserWebRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $assetreqhd = $this->repository->create($attributes);

            return redirect(trans_url('/user/assetrequest/assetreqhd'))
                -> with('message', trans('messages.success.created', ['Module' => trans('assetrequest::assetreqhd.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Assetreqhd $assetreqhd
     *
     * @return Response
     */
    public function edit(AssetreqhdUserWebRequest $request, Assetreqhd $assetreqhd)
    {

        Form::populate($assetreqhd);

        return $this->theme->of('assetrequest::user.assetreqhd.edit', compact('assetreqhd'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Assetreqhd $assetreqhd
     *
     * @return Response
     */
    public function update(AssetreqhdUserWebRequest $request, Assetreqhd $assetreqhd)
    {
        try {
            $this->repository->update($request->all(), $assetreqhd->getRouteKey());

            return redirect(trans_url('/user/assetrequest/assetreqhd'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('assetrequest::assetreqhd.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(AssetreqhdUserWebRequest $request, Assetreqhd $assetreqhd)
    {
        try {
            $this->repository->delete($assetreqhd->getRouteKey());
            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('assetrequest::assetreqhd.name')]),
                'code'     => 202,
                'redirect' => trans_url('/user/assetrequest/assetreqhd/0'),
            ], 202);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
